# GOV.UK Mini Environment Admin
# Copyright © 2018  Christopher Baines <mail@cbaines.net>
#
# This file is part of the GOV.UK Mini Environment Admin.
#
# The GOV.UK Mini Environment Admin is free software: you can
# redistribute it and/or modify it under the terms of the GNU Affero
# General Public License as published by the Free Software Foundation,
# either version 3 of the License, or (at your option) any later
# version.
#
# The GOV.UK Mini Environment Admin is distributed in the hope that it
# will be useful, but WITHOUT ANY WARRANTY; without even the implied
# warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
# See the GNU Affero General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public
# License along with the GOV.UK Mini Environment Admin.  If not, see
# <http://www.gnu.org/licenses/>.

# == Schema Information
#
# Table name: govuk_guix_data_snapshots
#
#  id                              :integer          not null, primary key
#  store_path                      :string           not null
#  archived                        :boolean          default(FALSE), not null
#  manifest                        :json             not null
#  created_at                      :datetime         not null
#  updated_at                      :datetime         not null
#  govuk_guix_revision_commit_hash :string           not null
#  backend_type                    :string
#  backend_id                      :integer
#

class GovukGuix::DataSnapshot < ApplicationRecord
  belongs_to(
    :govuk_guix_revision,
    class_name: 'GovukGuix::Revision',
    foreign_key: 'govuk_guix_revision_commit_hash'
  )
  belongs_to :backend, polymorphic: true, optional: true

  def description
    extracts_by_database = manifest['extracts']

    dates = extracts_by_database.flat_map do |_, extracts|
      extracts.map do |extract|
        extract['datetime']
      end
    end

    all_services = extracts_by_database.flat_map do |_, extracts|
      extracts.map do |extract|
        extract['services']
      end
    end

    "#{dates.uniq.join(', ')}: #{all_services.join(', ')}"
  end
end
