require 'integration_test_helper'

class Backends::TerraformLibvirtControllerTest < ActionDispatch::IntegrationTest
  setup do
    login_as User.new(name: 'Test', email: 'test@example.com')
  end

  test 'new' do
    get new_terraform_aws_backend_path
    assert_response :success
  end

  test 'create' do
    attributes = {
      label: 'Test Backend',
      domain: 'test.backend.example.com',
      uri: 'test://uri'
    }

    post(
      terraform_libvirt_backends_path,
      params: {
        backends_terraform_libvirt: attributes
      }
    )

    assert_response :redirect
    follow_redirect!
    assert_response :success

    backend = Backends::TerraformLibvirt.last
    attributes.each do |(key, value)|
      assert_equal backend.send(key), value
    end
  end

  test 'update' do
    backend = Backends::TerraformLibvirt.create(
      label: 'Old label',
      domain: 'old.domain.example.com',
      uri: 'old://uri'
    )

    new_attributes = {
      label: 'New label'
    }

    put(
      terraform_libvirt_backend_path(backend),
      params: {
        backends_terraform_libvirt: new_attributes
      }
    )

    assert_response :success
  end

  test 'show' do
    backend = Backends::TerraformLibvirt.create(
      label: 'Test Backend',
      domain: 'test.backend.example.com',
      uri: 'test://uri'
    )

    get terraform_libvirt_backend_path(backend)

    assert_response :success
  end

  test 'destroy' do
    backend = Backends::TerraformLibvirt.create(
      label: 'Test Backend',
      domain: 'test.backend.example.com',
      uri: 'test://uri'
    )

    delete terraform_libvirt_backend_path(backend)

    assert_response :redirect
  end
end
